@@ -18,6 +18,9 @@ DEFAULTS = {   # Default setting values
         '//cdnjs.cloudflare.com/ajax/libs/codemirror/3.20.0/mode/markdown/'
         'markdown.min.js'
     ),
+    'SHOWDOWN_JS_URL': (
+        '//cdnjs.cloudflare.com/ajax/libs/showdown/0.3.1/showdown.min.js'
+    )
 }
 
 
@@ -32,3 +35,5 @@ class GhostdownConf(AppConf):
     JQUERY_URL = _get_setting('JQUERY_URL')
     CODEMIRROR_JS_URL = _get_setting('CODEMIRROR_JS_URL')
     CODEMIRROR_MARKDOWN_JS_URL = _get_setting('CODEMIRROR_MARKDOWN_JS_URL')
+    SHOWDOWN_JS_URL = _get_setting('SHOWDOWN_JS_URL')
+    USE_LIVE_PREVIEW = False
