@@ -13,8 +13,12 @@ __all__ = ['GhostdownInput', 'GHOSTDOWN_INPUT_TEMPLATE_STRING']
 
 
 class GhostdownInput(widgets.HiddenInput):
-    def __init__(self, attrs=None, value_path=''):
+    def __init__(self, attrs=None, live_preview=None, value_path=''):
         super(GhostdownInput, self).__init__(attrs)
+        if live_preview is None:
+            self.live_preview = settings.GHOSTDOWN_USE_LIVE_PREVIEW
+        else:
+            self.live_preview = live_preview
         if value_path:
             self.value_path = value_path
 
@@ -29,25 +33,32 @@ class GhostdownInput(widgets.HiddenInput):
             pass
         original = super(GhostdownInput, self).render(name, value, attrs)
         original_id = attrs['id']
+        ghostdown_feature_id = '{0}_ghosteditor_feature'.format(original_id)
         ghostdown_id = '{0}_ghosteditor_markdown'.format(original_id)
         context = Context({
             'original': original,
             'original_id': original_id,
+            'ghostdown_feature_id': ghostdown_feature_id,
             'ghostdown_id': ghostdown_id,
             'content': value or '',
+            'live_preview': self.live_preview,
         })
         return self.get_template().render(context)
 
     @property
     def media(self):
         css = {
-            'all': (
+            'all': [
                 'ghostdown/css/ghostdown.css',
-            )
+            ]
         }
-        js = (
+        js = [
             settings.GHOSTDOWN_JQUERY_URL,
             settings.GHOSTDOWN_CODEMIRROR_JS_URL,
             settings.GHOSTDOWN_CODEMIRROR_MARKDOWN_JS_URL,
-        )
+            settings.GHOSTDOWN_SHOWDOWN_JS_URL,
+            'ghostdown/js/ghostdown.js',
+        ]
+        if self.live_preview:
+            css['all'].append('ghostdown/css/preview.css')
         return Media(css=css, js=[p for p in js if p])
